==> v0.96.zip: chrono/chrono/manager/utils.py <==
# chrono - agendas system
# Copyright (C) 2016-2017  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.db import transaction

from chrono.agendas.models import Agenda, AgendaImportError


def export_site():
    '''Dump site objects to JSON-dumpable dictionnary'''
    data = {}
    data['agendas'] = [x.export_json() for x in Agenda.objects.all()]
    return data


def import_site(data, if_empty=False, clean=False, overwrite=False):
    if if_empty and Agenda.objects.count():
        return

    if clean:
        Agenda.objects.all().delete()

    results = {'created': 0, 'updated': 0}
    with transaction.atomic():
        for data in data.get('agendas', []):
            created = Agenda.import_json(data, overwrite=overwrite)
            if created:
                results['created'] += 1
            else:
                results['updated'] += 1
    return results

==> v1.17.zip: chrono/chrono/manager/utils.py <==
# chrono - agendas system
# Copyright (C) 2016-2017  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import itertools

from django.db import transaction
from django.db.models import Q

from chrono.agendas.models import Agenda, AgendaImportError


def export_site():
    '''Dump site objects to JSON-dumpable dictionnary'''
    data = {}
    qs1 = Agenda.objects.filter(~Q(kind='virtual'))
    qs2 = Agenda.objects.filter(kind='virtual')
    data['agendas'] = [x.export_json() for x in itertools.chain(qs1, qs2)]
    return data


def import_site(data, if_empty=False, clean=False, overwrite=False):
    if if_empty and Agenda.objects.count():
        return

    if clean:
        Agenda.objects.all().delete()

    results = {'created': 0, 'updated': 0}
    with transaction.atomic():
        for data in data.get('agendas', []):
            created = Agenda.import_json(data, overwrite=overwrite)
            if created:
                results['created'] += 1
            else:
                results['updated'] += 1
    return results
